################################### load R packages ###################################
library(survival)
library(survcomp)

################################### Path set up ###################################
Path_fun = ".../"
Path_data = ".../"
Path_results = ".../"

################################### 1. Read in data ############################### 
# GSE24450
pheData_HEBCS = read.table(paste(Path_data,"pd_FINAL_20100827.txt",sep=""),header=TRUE,sep="\t")
gexData_mRNA_HEBCS = read.table(paste(Path_data,"mRNA_norm_select.txt",sep=""),header=TRUE,sep="\t")
Var_status_HEBCS = "BDDM"
Var_time_HEBCS = "TimeToBDDM"
Cov_age_HEBCS = "Dage"

# GSE4922
gexData_gse4922 = read.table(paste(Path_data,"GSE4922_GPL96_GEX_select.txt",sep=""),sep="\t",head=T)
pheData_gse4922 = read.table(paste(Path_data,"GSE4922_GPL96_phenotype.txt",sep=""),sep="\t",head=T)
Var_status_gse4922 = "Event_DFS"
Var_time_gse4922 = "Time_DFS_month"
gexData_gse4922 = gexData_gse4922[,-1]

# GSE25307
gexData_gse25307 = read.table(paste(Path_data,"GSE25307_GEX_select.txt",sep=""),sep="\t",head=T)
pheData_gse25307 = read.table(paste(Path_data,"GSE25307_phenotype.txt",sep=""),sep="\t",head=T,fill=T)
Var_status_gse25307 = "OSBIN"
Var_time_gse25307 = "Month_OS" 
gexData_gse25307 = gexData_gse25307[,-1]

# TCGA
pheData_TCGA = read.table(paste(Path_data,"TCGA_phenotype_GWS_515_samples.txt",sep=""),header=TRUE,sep="\t")
gexData_TCGA = read.table(paste(Path_data,"TCGA_mRNA_GWS_515_samples_select.txt",sep=""),header=TRUE,sep="\t")
phenoSample = gsub("-",".",as.character(pheData_TCGA[,1]))
ind_pheno = pmatch(colnames(gexData_TCGA)[-1],phenoSample)
pheData_TCGA=pheData_TCGA[ind_pheno,]
Var_status_TCGA = "VitalStatus"
Var_time_TCGA = "TimeToVitalStatus_Month"

# GLEDBLS
GLEDBLS <- read.table(file = paste(Path_data,"GLEDBLS.txt",sep=""), sep = "\t",header = TRUE,stringsAsFactors = FALSE)

################################### 2. Figure 1 ###############################
gene = "EPS15"
source(paste(Path_fun,"SurvivalAnalyzer_GEX_suv_single.R",sep=""))
layout(t(matrix(1:6,3,2)))
par(mar=c(5, 5, 4, 4))
#par(las = 1)
# GSE24450
Results_mRNA_HEBCS_main = SurvivalAnalyzer_GEX_suv_single(Path_results,"GSE24450",gene,gene,gexData_mRNA_HEBCS,pheData_HEBCS,Var_status_HEBCS, Var_time_HEBCS)
# GSE4922
Results_mRNA_GSE4922_main = SurvivalAnalyzer_GEX_suv_single(Path_results,"GSE4922",gene,gene,gexData_gse4922,pheData_gse4922,Var_status_gse4922, Var_time_gse4922) #
# GSE25307
Results_mRNA_GSE25307_main = SurvivalAnalyzer_GEX_suv_single(Path_results,"GSE25307",gene,gene,gexData_gse25307,pheData_gse25307,Var_status_gse25307, Var_time_gse25307) #
# TCGA
Results_mRNA_TCGA_main = SurvivalAnalyzer_GEX_suv_single(Path_results,"TCGA",gene,gene,gexData_TCGA,pheData_TCGA,Var_status_TCGA, Var_time_TCGA)
# GLEDBLS
p <- hazard.ratio(GLEDBLS$EPS15,GLEDBLS$Time,GLEDBLS$Event,method.test = c("logrank"))$p.value
hr <- hazard.ratio(GLEDBLS$EPS15,GLEDBLS$Time,GLEDBLS$Event,method.test = c("logrank"))$hazard.ratio
km<- survfit(Surv(Time, Event) ~ EPS15, data = GLEDBLS)
plot(km, col = c('#8B3E2F','#00688B'),lwd = 5:5,mark.time = TRUE,cex.axis = 2)
legend("bottomleft",c("low","high"),col=c('#8B3E2F','#00688B'),lwd = 5:5,cex = 1.5) 
text(diff(par("usr")[1:2])/11.5,sum(par("usr")[3:4])/4,paste("p=",round(p,10)),cex = 1.5)
text(diff(par("usr")[1:2])/10,sum(par("usr")[3:4])/5,paste("HR=",sprintf("%.2f",as.numeric(hr)),sep=""),cex = 1.5)
title(paste("GLEDBLS",sep=""))


