SurvivalAnalyzer_GEX_suv_single <- function(Path_results,name,gene,ID,gexData,phenoData,Var_status, Var_time){
	# Path_pheno: path for the pheno data
	# Path_gex: path for the gene expression data
	# Path_output: path for the output
	# fileName_pheno: file name for the pheno data
	# fileName_gex: file name for the gene expression data: the gene names should be in the 1st column of the data file
	# fileName_output: file name for the survival analysis results
	# Var_status: variable name for the "status" in the pheno data
	# Var_time: variable name for "time" in the pheno data

	library(survival)
	matDATA = gexData[,-1]
	Genes= gexData[,1]

	ind = which(Genes == ID)
	gex = matDATA[ind,]
	## 2.1. Build survival object
	pNames = names(phenoData)
	status = as.numeric(phenoData[,which(pNames==Var_status)])
	time = as.numeric(phenoData[,which(pNames==Var_time)])
	ind_rm = which(status=="888")
	if (length(ind_rm)!=0){
		status = status[-ind_rm]
		time = time[-ind_rm]
		gex = gex[-ind_rm]
	}
	Object_surv = Surv(time,status)
	L2 = length(gex)
	## 2.2. Run survival analysis	
	Med = as.numeric(median(gex[!is.na(gex)]))
    Exp = rep(-1,L2)
    Exp[which(gex>=Med)] = 1
    Exp[which(gex<Med)] = 0
    #tab = table(Exp)
    tabName = c("low","high")
    SDF = survdiff(Object_surv~Exp)
    p = as.numeric(1-pchisq(SDF$chisq,length(SDF$n)-1))
    odd = SDF$obs/(SDF$n-SDF$obs)
    hr = formatC(round(as.numeric(odd[2]/odd[1]),2),2,format="f") ## high:low
    #if (p<0.01) {p=format(p,scientific=T,digits=3)}
    #if (p<0.01) {p=round(p,3)}
    #if (p>=0.01) {p=round(p,2)}
    #dev.new()
    #savefig(paste(Path_results,gene,"/",gene,name,sep=""),height=10,width=224/19,type="pdf")
    #plot(survfit(Object_surv~Exp),xlab="Survival time (months)", ylab="Survival probability",col=c("blue","red"),lty=c(1:2))	
	plot(survfit(Object_surv~Exp),col=c('#8B3E2F','#00688B'),lwd = 5:5,mark.time = TRUE,cex.axis = 2)	
	#plot(km, col = c('blue','red'),lwd = 3:3,mark.time = TRUE,cex.axis = ki)
	legend("bottomleft",tabName,col=c('#8B3E2F','#00688B'),lwd = 5:5,cex = 1.5) 

	text(diff(par("usr")[1:2])/11.5,sum(par("usr")[3:4])/4,paste("p=",sprintf("%.3f",as.numeric(p)),sep=""),cex = 1.5)
	text(diff(par("usr")[1:2])/10,sum(par("usr")[3:4])/5,paste("HR=",sprintf("%.2f",as.numeric(hr)),sep=""),cex = 1.5)
	title(paste(name,sep=""))
	Results = cbind(gene,p,hr)
	colnames(Results) = c(gene,"p_value","HR")

	return(Results)
}
